==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/General/converter/translations/converter_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Converter</name>
    <message>
        <location filename="../converter.cpp" line="169"/>
        <source>Track: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="171"/>
        <source>Preset: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="266"/>
        <source>Encoding...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConverterDialog</name>
    <message>
        <location filename="../converterdialog.ui" line="14"/>
        <source>Converter Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="29"/>
        <source>Select tracks to convert:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="43"/>
        <source>Output directory:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="53"/>
        <source>Output file name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="63"/>
        <source>Preset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="73"/>
        <source>Overwrite existing files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="90"/>
        <source>Choose a directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="110"/>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="111"/>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="112"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="113"/>
        <source>Track number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="114"/>
        <source>Two-digit track number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="115"/>
        <source>Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="116"/>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="117"/>
        <source>Composer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="118"/>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="119"/>
        <source>Disc number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="120"/>
        <source>File name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="121"/>
        <source>Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="122"/>
        <source>Condition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="128"/>
        <source>Create</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="129"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="130"/>
        <source>Create a copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="131"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConverterFactory</name>
    <message>
        <location filename="../converterfactory.cpp" line="28"/>
        <source>Converter Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="49"/>
        <source>About Converter Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="50"/>
        <source>Qmmp Converter Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="51"/>
        <source>This plugin converts supported audio files to other file formats using external command-line encoders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConverterHelper</name>
    <message>
        <location filename="../converterhelper.cpp" line="35"/>
        <source>Convert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="36"/>
        <source>Meta+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="42"/>
        <source>Converting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="43"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="29"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="35"/>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="45"/>
        <source>Extension:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="58"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="77"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="83"/>
        <source>Write tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="90"/>
        <source>Convert to 16 bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="37"/>
        <source>%1 (Read Only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="70"/>
        <source>Output file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="71"/>
        <source>Input file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-0.9.8.tar.bz2: qmmp-0.9.8/src/plugins/General/converter/translations/converter_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>Converter</name>
    <message>
        <location filename="../converter.cpp" line="169"/>
        <source>Track: %1</source>
        <translation>Piste: %1</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="171"/>
        <source>Preset: %1</source>
        <translation>Préréglages: %1</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="266"/>
        <source>Encoding...</source>
        <translation>Encodage...</translation>
    </message>
</context>
<context>
    <name>ConverterDialog</name>
    <message>
        <location filename="../converterdialog.ui" line="14"/>
        <source>Converter Settings</source>
        <translation>Paramètres du Convertisseur</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="29"/>
        <source>Select tracks to convert:</source>
        <translation>Sélectionner les pistes à convertir:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="43"/>
        <source>Output directory:</source>
        <translation>Répertoire de sortie</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="53"/>
        <source>Output file name:</source>
        <translation>Nom du fichier de sortie</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="63"/>
        <source>Preset:</source>
        <translation>Préréglages:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="73"/>
        <source>Overwrite existing files</source>
        <translation>Écraser les fichiers éxistants</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="90"/>
        <source>Choose a directory</source>
        <translation>Choisir un répertoire</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="110"/>
        <source>Artist</source>
        <translation>Artiste</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="111"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="112"/>
        <source>Album Artist</source>
        <translation>Artiste</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="113"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="114"/>
        <source>Track Number</source>
        <translation>Numéro de piste</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="115"/>
        <source>Two-digit Track Number</source>
        <translation>Nombre à deux chiffres de piste</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="120"/>
        <source>Disc Number</source>
        <translation>Numéro du disque</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="121"/>
        <source>File Name</source>
        <translation>Nom du fichier</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="122"/>
        <source>File Path</source>
        <translation>Chemin du fichier</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="132"/>
        <source>Create a Copy</source>
        <translation>Crée une copie</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="116"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="117"/>
        <source>Comment</source>
        <translation>Commentaire</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="118"/>
        <source>Composer</source>
        <translation>Compositeur</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="119"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="123"/>
        <source>Year</source>
        <translation>Année</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="124"/>
        <source>Condition</source>
        <translation>Condition</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="130"/>
        <source>Create</source>
        <translation>Créer</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="131"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="133"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>ConverterFactory</name>
    <message>
        <location filename="../converterfactory.cpp" line="28"/>
        <source>Converter Plugin</source>
        <translation>Plugin de conversion</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="49"/>
        <source>About Converter Plugin</source>
        <translation>A propos du plugin de conversion</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="50"/>
        <source>Qmmp Converter Plugin</source>
        <translation>Plugin de conversion Qmmp</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="51"/>
        <source>This plugin converts supported audio files to other file formats using external command-line encoders</source>
        <translation>Ce plugin convertit les fichiers audio supportés vers les autres formats de fichiers utilisés par les encodeurs externes en ligne de commande</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Écrit par: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>ConverterHelper</name>
    <message>
        <location filename="../converterhelper.cpp" line="35"/>
        <source>Convert</source>
        <translation>Convertir</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="36"/>
        <source>Meta+C</source>
        <translation>Meta+C</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="42"/>
        <source>Converting...</source>
        <translation>En conversion...</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Préréglages de l&apos;éditeur</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="29"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="35"/>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="45"/>
        <source>Extension:</source>
        <translation>Extension:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="58"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="77"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="83"/>
        <source>Write tags</source>
        <translation>Écrire les tags</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="90"/>
        <source>Convert to 16 bit</source>
        <translation>Convertir en 16 bit</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="37"/>
        <source>%1 (Read Only)</source>
        <translation>%1 (Lecture Seule)</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="70"/>
        <source>Output file</source>
        <translation>Fichier de sortie</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="71"/>
        <source>Input file</source>
        <translation>Fichier d&apos;entrée</translation>
    </message>
</context>
</TS>
